@@ -3,14 +3,15 @@
 # Modules
 from bs4 import BeautifulSoup
 
-from . import encoding
-from nova.internal.building import NovaBuilder
+from nova import __encoding__
+from . import Plugin
 
 # Handle plugin
-class NoncePlugin:
-    def __init__(self, builder: NovaBuilder, config: dict) -> None:
-        self.nonce = config["nonce"]
-        self.destination = builder.destination
+class NoncePlugin(Plugin):
+    def __init__(self, *args) -> None:
+        super().__init__(*args)
+        self.nonce = self.config["nonce"]
+        self.destination = self.builder.destination
 
     def on_build(self, dev: bool) -> None:
         if dev:
@@ -20,7 +21,7 @@ class NoncePlugin:
             if file.suffix != ".html":
                 continue
 
-            root = BeautifulSoup(file.read_text(encoding), "lxml")
+            root = BeautifulSoup(file.read_text(__encoding__), "lxml")
             for element in root.select("script, link, style"):
                 if element.name == "link" and element.get("rel") != ["stylesheet"]:
                     continue
